@@ -1,6 +1,6 @@
 ## no critic (RequireUseStrict)
 package Dist::Zilla::PluginBundle::Author::RHOELZ;
-$Dist::Zilla::PluginBundle::Author::RHOELZ::VERSION = '0.06';
+$Dist::Zilla::PluginBundle::Author::RHOELZ::VERSION = '0.07';
 ## use critic (RequireUseStrict)
 use strict;
 use warnings;
@@ -191,7 +191,7 @@ sub configure {
     ]);
 
     $self->add_plugins([
-        GatherDir => {
+        'Git::GatherDir' => {
             include_dotfiles => 1,
         },
     ]);
@@ -224,7 +224,6 @@ sub configure {
     ]);
 
     $self->add_plugins(
-        'Git::ExcludeUntracked',
         'CheckChangesHasContent',
         'ConfirmRelease',
         'UploadToCPAN',
@@ -249,7 +248,7 @@ Dist::Zilla::PluginBundle::Author::RHOELZ - BeLike::RHOELZ when you build your d
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -283,7 +282,7 @@ equivalent to the following:
   type     = pod
   filename = README.pod
   location = root
-  [GatherDir]
+  [Git::GatherDir]
   include_dotfiles = 1
   [PruneCruft]
   except = \.perlcriticrc
@@ -302,7 +301,6 @@ equivalent to the following:
   [PruneFiles]
   filename = dist.ini
   filename = weaver.ini
-  [Git::ExcludeUntracked]
   [CheckChangesHasContent]
   [ConfirmRelease]
   [UploadToCPAN]
